@@ -148,7 +148,7 @@ CI_set_num_fields(ColumnInfoClass *self, int new_num_fields)
 
 
 void
-CI_set_field_info(ColumnInfoClass *self, int field_num, char *new_name,
+CI_set_field_info(ColumnInfoClass *self, int field_num, const char *new_name,
 		OID new_adtid, Int2 new_adtsize, Int4 new_atttypmod,
 		OID new_relid, OID new_attid)
 {
