@@ -1837,7 +1837,7 @@ CC_send_query_append(ConnectionClass *self, const char *query, QueryInfo *qi, UD
 		QResultHold rholda;
 
 		rhold = CC_send_query_append(self, query, qi, flag, stmt, NULL);
-		if (QR_command_maybe_successful(res))
+		if (QR_command_maybe_successful(rhold.first))
 		{
 			rholda = CC_send_query_append(self, appendq, qi, flag & (~(GO_INTO_TRANSACTION)), stmt, NULL);
 			if (QR_command_maybe_successful(rholda.first))
@@ -3263,10 +3263,13 @@ DLL_DECLARE int PgDtc_is_recovery_available(void *self, char *reason, int rsize)
 	/*
 	 * Did we use SSL client certificate, SSPI, Kerberos or similar
 	 * authentication methods?
-	 * There seems no way to check it directly.
 	 */
 	doubtCert = FALSE;
+#ifdef HAVE_PQSSLINUSE
+	if (PQsslInUse(conn->pqconn))
+#else
 	if (PQgetssl(conn->pqconn) != NULL)
+#endif
 		doubtCert = TRUE;
 
 	nameSize = sizeof(loginUser);
