@@ -458,6 +458,12 @@ PGAPI_GetConnectAttr(HDBC ConnectionHandle,
 		case SQL_ATTR_PGOPT_MSJET:
 			*((SQLINTEGER *) Value) = conn->ms_jet;
 			break;
+		case SQL_ATTR_PGOPT_BATCHSIZE:
+			*((SQLINTEGER *) Value) = conn->connInfo.batch_size;
+			break;
+		case SQL_ATTR_PGOPT_IGNORETIMEOUT:
+			*((SQLINTEGER *) Value) = conn->connInfo.ignore_timeout;
+			break;
 		default:
 			ret = PGAPI_GetConnectOption(ConnectionHandle, (UWORD) Attribute, Value, &len, BufferLength);
 	}
@@ -1785,6 +1791,14 @@ PGAPI_SetConnectAttr(HDBC ConnectionHandle,
 			conn->ms_jet = CAST_PTR(SQLINTEGER, Value);
 			MYLOG(0, "ms_jet => %d\n", conn->ms_jet);
 			break;
+		case SQL_ATTR_PGOPT_BATCHSIZE:
+			conn->connInfo.batch_size = CAST_PTR(SQLINTEGER, Value);
+			MYLOG(0, "batch size => %d\n", conn->connInfo.batch_size);
+			break;
+		case SQL_ATTR_PGOPT_IGNORETIMEOUT:
+			conn->connInfo.ignore_timeout = CAST_PTR(SQLINTEGER, Value);
+			MYLOG(0, "ignore_timeout => %d\n", conn->connInfo.ignore_timeout);
+			break;
 		default:
 			if (Attribute < 65536)
 				ret = PGAPI_SetConnectOption(ConnectionHandle, (SQLUSMALLINT) Attribute, (SQLLEN) Value);
